#ifndef ARBNIOINT_HPP
#define ARBNIOINT_HPP

#include "ArbreN.hpp"

// Lectura d'un arbre N-ari d'enters, acci.  Els elements
// s'introdueixen en preordre: primer l'arrel, desprs els N
// fills. Els arbres buits es representen amb la marca. Noteu que el
// nombre de fills s'ha de llegir previament per poder declarar
// l'arbre abans de la crida.

/* Exemple: l'arbre 

     1
   / | \
  2  4  3

   es llegeix 1 2 0 0 0 4 0 0 0 3 0 0 0 

  com que poden haver fills buits, la segent entrada

  1 2 0 0 0 0 3 0 0 0 

  representa l'arbre

     1
   / | \
  2  -  3

  on el segon fill es buit
*/

void llegir_arbreN_int(ArbreNari<int>& a, int marca){
/* Pre: a es buit; el canal estandar d'entrada cont el recorregut en preordre
   d'un arbre general A d'enters marcat amb "marca" */  
/* Post: a = A */
  int x;
  cin >> x;
  if (x!= marca) {
    int m= a.aritat();
    vector<ArbreNari<int> > va(m,ArbreNari<int>(m));
    for (int i=0; i<m; ++i)
      llegir_arbreN_int(va[i], marca);
    a.plantar(x,va);
  }
}

// Escriptura d'un arbre general d'enteros, acci.  Els elements 
// s'escriuen tamb en preordre

/* Exemple: l'arbre 

     1
   / | \
  2  4  3

   s'escriu 1 2 4 3 */

void escriure_arbreN_int(ArbreNari<int> &a) {
/* Pre: cert */ 
/* Post: El canal estandar de sortida cont el recorregut en preordre d'a */ 
  if (not a.es_buit()) {
    int x = a.arrel();
    int m= a.aritat();
    vector<ArbreNari<int> > va;
    a.fills(va);
    cout << x << " ";
    for (int i=0; i<m; ++i)
      escriure_arbreN_int(va[i]); 
    a.plantar(x,va);    
  }
}

#endif
